==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/V_UNYSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.V_UNY;
import io.ciera.tool.sql.ooaofooa.value.V_UNYSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class V_UNYSetImpl extends InstanceSet<V_UNYSet,V_UNY> implements V_UNYSet {

    // attributes
    @Override
    public void setOperator( String m_Operator ) throws XtumlException {
        for ( V_UNY v_uny : this ) v_uny.setOperator( m_Operator );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( V_UNY v_uny : this ) v_uny.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setOperand_Value_ID( UniqueId ref_Operand_Value_ID ) throws XtumlException {
        for ( V_UNY v_uny : this ) v_uny.setOperand_Value_ID( ref_Operand_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( V_UNY v_uny : this ) valueset.add( v_uny.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public ValueSet R804_has_operand_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( V_UNY v_uny : this ) valueset.add( v_uny.R804_has_operand_Value() );
        return valueset;
    }


    @Override
    public V_UNY nullElement() {
        return V_UNYImpl.EMPTY_V_UNY;
    }

    @Override
    public V_UNYSet emptySet() {
      return new V_UNYSetImpl();
    }

    @Override
    public V_UNYSet value() {
        return this;
    }

    @Override
    public List<V_UNY> elements() {
        return Arrays.asList(toArray(new V_UNY[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/V_UNYSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.V_UNY;
import io.ciera.tool.sql.ooaofooa.value.V_UNYSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class V_UNYSetImpl extends InstanceSet<V_UNYSet,V_UNY> implements V_UNYSet {

    public V_UNYSetImpl() {
    }

    public V_UNYSetImpl(Comparator<? super V_UNY> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setOperator( String m_Operator ) throws XtumlException {
        for ( V_UNY v_uny : this ) v_uny.setOperator( m_Operator );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( V_UNY v_uny : this ) v_uny.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setOperand_Value_ID( UniqueId ref_Operand_Value_ID ) throws XtumlException {
        for ( V_UNY v_uny : this ) v_uny.setOperand_Value_ID( ref_Operand_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( V_UNY v_uny : this ) valueset.add( v_uny.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public ValueSet R804_has_operand_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( V_UNY v_uny : this ) valueset.add( v_uny.R804_has_operand_Value() );
        return valueset;
    }


    @Override
    public V_UNY nullElement() {
        return V_UNYImpl.EMPTY_V_UNY;
    }

    @Override
    public V_UNYSet emptySet() {
      return new V_UNYSetImpl();
    }

    @Override
    public V_UNYSet emptySet(Comparator<? super V_UNY> comp) {
      return new V_UNYSetImpl(comp);
    }

    @Override
    public V_UNYSet value() {
        return this;
    }

    @Override
    public List<V_UNY> elements() {
        return Arrays.asList(toArray(new V_UNY[0]));
    }

}
